# Storybook for HTML

---

Storybook for HTML is a UI development environment for your plain HTML snippets.
With it, you can visualize different states of your UI components and develop them interactively.

![Storybook Screenshot](https://github.com/storybooks/storybook/blob/master/media/storybook-intro.gif)

Storybook runs outside of your app.
So you can develop UI components in isolation without worrying about app specific dependencies and requirements.

## Getting Started

```sh
cd my-app
npx -p @storybook/cli sb init -t html
```

For more information visit: [storybook.js.org](https://storybook.js.org)

---

Storybook also comes with a lot of [addons](https://storybook.js.org/addons/introduction) and a great API to customize as you wish.
You can also build a [static version](https://storybook.js.org/basics/exporting-storybook) of your storybook and deploy it anywhere you want.


## Examples


```
/* global document */
import { storiesOf } from 'storybook-html';

storiesOf('Demo', module)
  .add('heading', () => '<h1>Hello World</h1>')
  .add('button', () => {
    let component = {
      template: "<h1>Hello World</h1>",
      styles: "h1 { color:red; }",
      scripts: "console.info('hello world');"
    }
	return component;
  });

```

## Decorator

You can also expose this functionality as a Storybook decorator and use it like this.

```
import { storiesOf, addDecorator, withStyles, withScripts } from 'storybook-html';

storiesOf('Demo', module)
  .addDecorator(withStyles({
  	style: `h1 { color: red }`
	}))
  .addDecorator(withScripts({
  	script: `console.log("withScripts");` 
  }))
```

You can also add a decorator globally for all stories like this.

```
import { addDecorator, withStyles } from 'storybook-html';

addDecorator(withStyles({style: `
  * {color: red;}
`}))
```

## build 


```
npm run build
```
or
```
npm pack
```