import { document, Node } from 'global';
import { stripIndents } from 'common-tags';

const rootElement = document.getElementById('root');
const headElement = document.head;
const bodyElement = document.body;

export default function renderMain({
  story,
  selectedKind,
  selectedStory,
  showMain,
  showError,
  forceRender,
}) {
  const component = story();
  let isDom = component instanceof HTMLElement;
  let styleElement = document.getElementById('sb-component-style');
  let scriptElement = document.getElementById('sb-component-script');

  if ( styleElement ) { styleElement.parentNode.removeChild(styleElement); }
  if ( scriptElement ) { scriptElement.parentNode.removeChild(scriptElement); }

  showMain();
  if (typeof component === 'object' && !isDom) {
    let { template, styles, scripts } = component;

    // Add costom style
    if ( styles ) {
      let styleElement = document.createElement('style');
      styleElement.setAttribute("id", "sb-component-style");
      styleElement.innerHTML = styles;
      headElement.appendChild(styleElement);
    }

    if ( template ) {
      rootElement.innerHTML = template.innerHTML || template;
    }
    
    // Add costom script
    if ( scripts ) {
      let scriptElement = document.createElement('script');
      scriptElement.setAttribute("id", "sb-component-script"); 
      scriptElement.innerHTML = scripts;
      bodyElement.appendChild(scriptElement);
    }

  } else if (typeof component === 'string') {
    rootElement.innerHTML = component;
  } else if (component instanceof Node) {
    if (forceRender === true) {
      return;
    }
    rootElement.innerHTML = '';
    rootElement.appendChild(component);
  } else {
    showError({
      title: `Expecting an HTML snippet or DOM node from the story: "${selectedStory}" of "${selectedKind}".`,
      description: stripIndents`
        Did you forget to return the HTML snippet from the story?
        Use "() => <your snippet or node>" or when defining the story.
      `,
    });
  }
}
