import addons, { makeDecorator } from '@storybook/addons';

const INNER_ID = 'sb-addon-handlebars-inner';
const WRAPPER_ID = 'sb-addon-handlebars-wrapper';

let iframeHead = document.head;
let iframeBody = document.body;
let storyNameCache = new URL(location.href).searchParams.get('selectedKind');


const withScripts = makeDecorator({
  name: 'withScripts',
  parameterName: 'Scripts',
  skipIfNoParametersOrOptions: true,
  wrapper: (getStory, context, { options, parameters }) => {
    const scripts = parameters || options || [];
    let storyName = context.kind;

    if (!scripts) return getStory(context);

    let body = iframeBody;
    let scriptElement = document.getElementById(`story-${storyName.toLowerCase()}-script`);
    if (!scriptElement) {
      scriptElement = document.createElement('script');
      scriptElement.setAttribute('id', `story-${storyName.toLowerCase()}-script`);
      body.appendChild(scriptElement);
    }
    scriptElement.innerHTML = scripts.script;

    return getStory(context);
  },
});

const withStyles = makeDecorator({
  name: 'withStyles',
  parameterName: 'Styles',
  skipIfNoParametersOrOptions: true,
  wrapper: (getStory, context, { options, parameters }) => {
    const styles = parameters || options || [];
    let storyName = context.kind;

    if (!styles) return getStory(context);

    let head = iframeHead;
    let styleElement = document.getElementById(`story-${storyName.toLowerCase()}-style`);

    if (!styleElement) {
      styleElement = document.createElement('style');
      styleElement.setAttribute('id', `story-${storyName.toLowerCase()}-style`);
      head.appendChild(styleElement);
    }
    styleElement.innerHTML = styles.style;

    return getStory(context);
  },
});

export { withStyles, withScripts };